@@ -224,6 +224,33 @@ G_BEGIN_DECLS
   g_value_set_enum (gimp_value_array_index (args, n), value)
 
 
+/*  choice  */
+
+#define GIMP_PROC_ARG_CHOICE(procedure, name, nick, blurb, choice, default, flags) \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_choice (name, nick, blurb,\
+                               choice, default,\
+                               flags))
+
+#define GIMP_PROC_AUX_ARG_CHOICE(procedure, name, nick, blurb, choice, default, flags) \
+  gimp_procedure_add_aux_argument (procedure,\
+                                   gimp_param_spec_choice (name, nick, blurb,\
+                                   choice, default,\
+                                   flags))
+
+#define GIMP_PROC_VAL_CHOICE(procedure, name, nick, blurb, enum_type, default, flags) \
+  gimp_procedure_add_return_value (procedure,\
+                                   gimp_param_spec_choice (name, nick, blurb,\
+                                   choice, default,\
+                                   flags))
+
+#define GIMP_VALUES_GET_CHOICE(args, n) \
+  g_value_get_int (gimp_value_array_index (args, n))
+
+#define GIMP_VALUES_SET_CHOICE(args, n, value) \
+  g_value_set_int (gimp_value_array_index (args, n), value)
+
+
 /*  string  */
 
 #define GIMP_PROC_ARG_STRING(procedure, name, nick, blurb, default, flags) \
@@ -257,6 +284,41 @@ G_BEGIN_DECLS
   g_value_take_string (gimp_value_array_index (args, n), value)
 
 
+/*  color  */
+
+/* TODO:
+ * 1. has_alpha is currently bogus and doesn't do anything yet.
+ * 2. Also wouldn't none_ok be useful for color arguments (accepting a NULL
+ *    GeglColor)?
+ * 3. GEGL also provides a gegl_param_spec_color_from_string() allowing to
+ *    initialize the default with a list of standard colors. Wouldn't it be
+ *    interesting to also have this?
+ */
+#define GIMP_PROC_ARG_COLOR(procedure, name, nick, blurb, has_alpha, default, flags) \
+  gimp_procedure_add_argument (procedure,\
+                               gegl_param_spec_color (name, nick, blurb,\
+                               default, \
+                               flags))
+
+#define GIMP_PROC_AUX_ARG_COLOR(procedure, name, nick, blurb, has_alpha, default, flags) \
+  gimp_procedure_add_aux_argument (procedure,\
+                                   gegl_param_spec_color (name, nick, blurb,\
+                                   default, \
+                                   flags))
+
+#define GIMP_PROC_VAL_COLOR(procedure, name, nick, blurb, has_alpha, default, flags) \
+  gimp_procedure_add_return_value (procedure,\
+                                   gegl_param_spec_color (name, nick, blurb,\
+                                   default, \
+                                   flags))
+
+#define GIMP_VALUES_GET_COLOR(args, n, value) \
+  g_value_get_object (gimp_value_array_index (args, n), value)
+
+#define GIMP_VALUES_SET_COLOR(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
+
 /*  rgb  */
 
 #define GIMP_PROC_ARG_RGB(procedure, name, nick, blurb, has_alpha, default, flags) \
@@ -367,7 +429,7 @@ G_BEGIN_DECLS
 #define GIMP_VALUES_DUP_BYTES(args, n) \
   g_value_dup_boxed (gimp_value_array_index (args, n))
 
-#define GIMP_VALUES_SET_BYTES(args, n, value, length) \
+#define GIMP_VALUES_SET_BYTES(args, n, value) \
   g_value_set_boxed (gimp_value_array_index (args, n), value)
 
 #define GIMP_VALUES_TAKE_BYTES(args, n, value, length) \
@@ -861,6 +923,12 @@ G_BEGIN_DECLS
 
 /*  Resource  */
 
+#define GIMP_PROC_ARG_RESOURCE(procedure, name, nick, blurb, flags)  \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_resource (name, nick, blurb,\
+                                                         GIMP_TYPE_RESOURCE,\
+                                                         flags))
+
 #define GIMP_PROC_ARG_BRUSH(procedure, name, nick, blurb, flags)  \
   gimp_procedure_add_argument (procedure,\
                                gimp_param_spec_brush (name, nick, blurb,\
