@@ -30,21 +30,22 @@
 #include <libgimp/gimpuitypes.h>
 
 #include <libgimp/gimpaspectpreview.h>
-#include <libgimp/gimpbrushselectbutton.h>
+#include <libgimp/gimpbrushchooser.h>
+#include <libgimp/gimpdrawablechooser.h>
 #include <libgimp/gimpdrawablepreview.h>
 #include <libgimp/gimpexport.h>
-#include <libgimp/gimpresourceselectbutton.h>
-#include <libgimp/gimpfontselectbutton.h>
-#include <libgimp/gimpgradientselectbutton.h>
+#include <libgimp/gimpfontchooser.h>
+#include <libgimp/gimpgradientchooser.h>
 #include <libgimp/gimpimagecombobox.h>
 #include <libgimp/gimpitemcombobox.h>
-#include <libgimp/gimppaletteselectbutton.h>
-#include <libgimp/gimppatternselectbutton.h>
+#include <libgimp/gimppalettechooser.h>
+#include <libgimp/gimppatternchooser.h>
 #include <libgimp/gimpprocbrowserdialog.h>
 #include <libgimp/gimpproceduredialog.h>
 #include <libgimp/gimpprocview.h>
 #include <libgimp/gimpprogressbar.h>
-#include <libgimp/gimppropchooserfactory.h>
+#include <libgimp/gimppropwidgets.h>
+#include <libgimp/gimpresourcechooser.h>
 #include <libgimp/gimpsaveproceduredialog.h>
 #include <libgimp/gimpzoompreview.h>
 
@@ -57,11 +58,7 @@ G_BEGIN_DECLS
 
 void        gimp_ui_init                          (const gchar *prog_name);
 
-GdkWindow * gimp_ui_get_progress_window           (void);
-
 void        gimp_window_set_transient             (GtkWindow   *window);
-
-GdkWindow * gimp_ui_get_display_window            (GimpDisplay *display);
 void        gimp_window_set_transient_for_display (GtkWindow   *window,
                                                    GimpDisplay *display);
 
