@@ -21,15 +21,18 @@
 
 #define __GIMP_BASE_H_INSIDE__
 
+#include <gegl.h>
+
 #include <libgimpbase/gimpbasetypes.h>
 
 #include <libgimpbase/gimpchecks.h>
+#include <libgimpbase/gimpchoice.h>
 #include <libgimpbase/gimpcpuaccel.h>
-#include <libgimpbase/gimpdatafiles.h>
 #include <libgimpbase/gimpenv.h>
 #include <libgimpbase/gimplimits.h>
 #include <libgimpbase/gimpmemsize.h>
 #include <libgimpbase/gimpmetadata.h>
+#include <libgimpbase/gimpparamspecs.h>
 #include <libgimpbase/gimpparasite.h>
 #include <libgimpbase/gimprectangle.h>
 #include <libgimpbase/gimpunit.h>
