@@ -239,4 +239,4 @@
 )
 
 (script-fu-menu-register "script-fu-blend-anim"
-                         "<Image>/Filters/Animation/Animators")
+                         "<Image>/Filters/Animation/")
