@@ -53,7 +53,7 @@
         (offy (carve-scale size 0.25))
         (feather (carve-scale size 0.3))
         (brush-size (carve-scale size 0.3))
-        (brush-name (car (gimp-brush-new "Carve It")))
+        (brush (car (gimp-brush-new "Carve It")))
         (mask (car (gimp-channel-new img width height "Engraving Mask" 50 '(0 0 0))))
         (inset-gamma (calculate-inset-gamma (car (gimp-item-get-image bg-layer)) bg-layer))
         (mask-fat 0)
@@ -103,15 +103,15 @@
     (gimp-image-insert-channel img mask-fat -1 0)
     (gimp-image-select-item img CHANNEL-OP-REPLACE mask-fat)
 
-    (gimp-brush-set-shape brush-name BRUSH-GENERATED-CIRCLE)
-    (gimp-brush-set-spikes brush-name 2)
-    (gimp-brush-set-hardness brush-name 1.0)
-    (gimp-brush-set-spacing brush-name 25)
-    (gimp-brush-set-aspect-ratio brush-name 1)
-    (gimp-brush-set-angle brush-name 0)
-    (cond (<= brush-size 17) (gimp-brush-set-radius brush-name (\ brush-size 2))
-	  (else gimp-brush-set-radius brush-name (\ 19 2)))
-    (gimp-context-set-brush brush-name)
+    (gimp-brush-set-shape brush BRUSH-GENERATED-CIRCLE)
+    (gimp-brush-set-spikes brush 2)
+    (gimp-brush-set-hardness brush 1.0)
+    (gimp-brush-set-spacing brush 25)
+    (gimp-brush-set-aspect-ratio brush 1)
+    (gimp-brush-set-angle brush 0)
+    (cond (<= brush-size 17) (gimp-brush-set-radius brush (\ brush-size 2))
+	  (else gimp-brush-set-radius brush (\ 19 2)))
+    (gimp-context-set-brush brush)
 
     (gimp-context-set-foreground '(255 255 255))
     (gimp-drawable-edit-stroke-selection mask-fat)
@@ -208,7 +208,7 @@
     (gimp-item-set-name cast-shadow-layer _"Cast Shadow")
     (gimp-item-set-name inset-layer _"Inset")
 
-    (gimp-brush-delete brush-name)
+    (gimp-resource-delete brush)
 
     (gimp-display-new img)
     (gimp-image-undo-enable img)
